@@ -230,7 +230,7 @@ do_message(char *msg)
     }
   else
     {
-      job_list = [[[[Gtk_CList alloc] initWithCListInfoTitles:4 Titles:collist] show] freeze];
+      job_list = [[[[Gtk_CList alloc] initWithTitles:4 :collist] show] freeze];
       [job_list set_selection_mode:GTK_SELECTION_BROWSE];
       [job_list set_column_width:0 :40];
       [job_list set_column_width:1 :200];
@@ -266,7 +266,7 @@ do_message(char *msg)
 	  vals[1] = (char *) [newprt->jobs[i] getJobFilenames];
 	  sprintf(vals[2], "%d", [newprt->jobs[i] getJobSize]);
 	  vals[3] = (char *) [newprt->jobs[i] getJobOwner];
-	  [job_list set_row_data:[job_list appendCListRow:(const char **)vals] rowData:newprt->jobs[i]];
+	  [job_list set_row_data:[job_list append:(const char **)vals] :newprt->jobs[i]];
 	}
       if (oldoffset >= 0)
 	[job_list select_row:oldoffset :0];
@@ -315,7 +315,7 @@ do_message(char *msg)
     }
   else
     {
-      printer_list = [[[[Gtk_CList alloc] initWithCListInfoTitles:4 Titles:(const char **)columns] show] freeze];
+      printer_list = [[[[Gtk_CList alloc] initWithTitles:4 :(const char **)columns] show] freeze];
       [printer_list set_selection_mode:GTK_SELECTION_BROWSE];
       [printer_list connectObj:"select_row" :self];
       [printer_list set_column_width:0 :60];
@@ -327,7 +327,7 @@ do_message(char *msg)
 
   for (cnt = 0; cnt < printsys->numprinters; cnt++)
     {
-      i = [printer_list appendCListRow:(const char **)columns];
+      i = [printer_list append:(const char **)columns];
       g_print(_("Doing row %d\n"), i);
       cp = printsys->printers[cnt];
 
@@ -345,7 +345,7 @@ do_message(char *msg)
       else
 	[printer_list set_pixmap:i :3 :no_pixmap :no_mask];
       g_print(_("Setting row data %d to %#lx\n"), i, (long) cp);
-      [printer_list set_row_data:i rowData:cp];
+      [printer_list set_row_data:i :cp];
     }
   g_free(tmp);
 
@@ -422,7 +422,7 @@ do_message(char *msg)
 
   mainwin = [[GULPMainWin alloc] initWithAppWinInfo:"gulp" : _("GNOME Unified Link to Printers")];
 
-  [mainwin set_usize:550 height:400];
+  [mainwin set_usize:550 :400];
   mainwin->app = self;
 
   /* Pixmaps */
@@ -440,40 +440,40 @@ do_message(char *msg)
 
   /* Printer queues */
 
-  table = [[[Gtk_Table alloc] initWithTableInfo:4 cntCols:2 isHomo:FALSE] set_border_width:6];
-  [table set_col_spacing:0 Spacing:4];
-  [table set_row_spacing:1 Spacing:4];
+  table = [[[Gtk_Table alloc] initWithTableInfo:4 :2 :FALSE] set_border_width:6];
+  [table set_col_spacing:0 :4];
+  [table set_row_spacing:1 :4];
   [table show];
   [mainwin set_contents:table];
 
-  label = [[[[Gtk_Label alloc] initWithLabel:_("Printer queues")]
-	     set_alignment:0.0 alignY:0.5] show];
+  label = [[[[Gtk_Label alloc] initWithLabelInfo:_("Printer queues")]
+	     set_alignment:0.0 :0.5] show];
   [table attach:label
-	 attachLeft:0 attachRight:1 attachTop:0 attachBottom:1
-	 optionsX:(GTK_EXPAND | GTK_FILL) optionsY:0
-	 paddingX:0 paddingY:0];
+	 :0 :1 :0 :1
+	 :(GTK_EXPAND | GTK_FILL) :0
+	 :0 :0];
 
   [self do_printer_list];
   [table attach:printer_list
-	 attachLeft:0 attachRight:1 attachTop:1 attachBottom:2
-	 optionsX:(GTK_EXPAND | GTK_FILL) optionsY:(GTK_EXPAND | GTK_FILL)
-	 paddingX:0 paddingY:0];
+	 :0 :1 :1 :2
+	 :(GTK_EXPAND | GTK_FILL) :(GTK_EXPAND | GTK_FILL)
+	 :0 :0];
 
-  vbox = [[[Gtk_VBox alloc] initWithBoxInfo:FALSE setSpacing:4] show];
+  vbox = [[[Gtk_VBox alloc] initWithVBoxInfo:FALSE :4] show];
   [table attach:vbox
-	 attachLeft:1 attachRight:2 attachTop:1 attachBottom:2
-	 optionsX:(GTK_FILL | GTK_SHRINK) optionsY:(GTK_EXPAND | GTK_FILL)
-	 paddingX:0 paddingY:0];
+	 :1 :2 :1 :2
+	 :(GTK_FILL | GTK_SHRINK) :(GTK_EXPAND | GTK_FILL)
+	 :0 :0];
 
   queueing    = [[[[Gtk_CheckButton alloc] initWithLabel:_("Queueing")] show] connectObj:"toggled" :self];
   printing    = [[[[Gtk_CheckButton alloc] initWithLabel:_("Printing")] show] connectObj:"toggled" :self];
   clear_queue = [[[[Gtk_Button alloc]      initWithLabel:_("Clear queue")] show] connectObj:"clicked" :self];
   restart     = [[[[Gtk_Button alloc]      initWithLabel:_("Restart daemon")] show] connectObj:"clicked" :self];
 
-  [vbox pack_start:queueing doExpand:FALSE doFill:FALSE doPadding:0];
-  [vbox pack_start:printing doExpand:FALSE doFill:FALSE doPadding:0];
-  [vbox pack_start:clear_queue doExpand:FALSE doFill:FALSE doPadding:0];
-  [vbox pack_start:restart doExpand:FALSE doFill:FALSE doPadding:0];
+  [vbox pack_start:queueing :FALSE :FALSE :0];
+  [vbox pack_start:printing :FALSE :FALSE :0];
+  [vbox pack_start:clear_queue :FALSE :FALSE :0];
+  [vbox pack_start:restart :FALSE :FALSE :0];
 
   /* Disable these buttons if we are not root */
 
@@ -482,28 +482,28 @@ do_message(char *msg)
 
   /* Jobs */
 
-  label = [[[[Gtk_Label alloc] initWithLabel:_("Jobs for selected printer")]
-	     set_alignment:0.0 alignY:0.5] show];
+  label = [[[[Gtk_Label alloc] initWithLabelInfo:_("Jobs for selected printer")]
+	     set_alignment:0.0 :0.5] show];
   [table attach:label
-	 attachLeft:0 attachRight:1 attachTop:2 attachBottom:3
-	 optionsX:(GTK_EXPAND | GTK_FILL) optionsY:0
-	 paddingX:0 paddingY:0];
+	 :0 :1 :2 :3
+	 :(GTK_EXPAND | GTK_FILL) :0
+	 :0 :0];
 
-  vbox = [[[Gtk_VBox alloc] initWithBoxInfo:FALSE setSpacing:4] show];
+  vbox = [[[Gtk_VBox alloc] initWithVBoxInfo:FALSE :4] show];
   [table attach:vbox
-	 attachLeft:1 attachRight:2 attachTop:3 attachBottom:4
-	 optionsX:(GTK_FILL | GTK_SHRINK) optionsY:(GTK_EXPAND | GTK_FILL)
-	 paddingX:0 paddingY:0];
+	 :1 :2 :3 :4
+	 :(GTK_FILL | GTK_SHRINK) :(GTK_EXPAND | GTK_FILL)
+	 :0 :0];
 
   cancel_job = [[[[[Gtk_Button alloc] initWithLabel:_("Cancel job")] show] connectObj:"clicked" :self] set_sensitive:FALSE];
 
   [self do_job_list];
   [table attach:job_list
-	 attachLeft:0 attachRight:1 attachTop:3 attachBottom:4
-	 optionsX:(GTK_EXPAND | GTK_FILL) optionsY:(GTK_EXPAND | GTK_FILL)
-	 paddingX:0 paddingY:0];
+	 :0 :1 :3 :4
+	 :(GTK_EXPAND | GTK_FILL) :(GTK_EXPAND | GTK_FILL)
+	 :0 :0];
 
-  [vbox pack_start:cancel_job doExpand:FALSE doFill:FALSE doPadding:0];
+  [vbox pack_start:cancel_job :FALSE :FALSE :0];
 
   [mainwin create_menus:mainmenu];
   gtk_menu_item_right_justify(GTK_MENU_ITEM(mainmenu[1].widget));
