@@ -21,6 +21,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <gtk/gtk.h>
+#include <config.h>
 #include <gnome.h>
 #include "logview.h"
 #include "log.xpm"
@@ -57,11 +58,11 @@ AboutRepaint (GtkWidget *widget, gpointer data)
   int lm = 20;              /*  left margin */
   int numlines = 5;
   char *other_info[] = {
-"This  program  is  part of  the  GNOME  project for  Linux.",
-"Logview comes with ABSOLUTELY NO WARRANTY. This",
-"is free software, and you are welcome to redistribute it",
-"under the conditions of the GNU General Public Licence. The ",
-"log icon is a courtesy of Tuomas Kuosmanen (a.k.a tigert)."};
+N_("This  program  is  part of  the  GNOME  project for  Linux."),
+N_("Logview comes with ABSOLUTELY NO WARRANTY. This"),
+N_("is free software, and you are welcome to redistribute it"),
+N_("under the conditions of the GNU General Public Licence. The "),
+N_("log icon is a courtesy of Tuomas Kuosmanen (a.k.a tigert).")};
 
 
   canvas = widget->window;
@@ -90,16 +91,16 @@ AboutRepaint (GtkWidget *widget, gpointer data)
 
   /* Draw title */
   gdk_gc_set_foreground (gc, &cfg->white);
-  sprintf(buffer, "Version %s", LOGVIEW_VERSION);
+  snprintf(buffer, 254, _("Version %s"), LOGVIEW_VERSION);
   gdk_draw_string (canvas, cfg->heading, gc, lm + column_x[1], y, buffer);
   y +=  h;
-  gdk_draw_string (canvas, cfg->heading, gc, lm + column_x[1], y, "Written by:");
+  gdk_draw_string (canvas, cfg->heading, gc, lm + column_x[1], y, _("Written by:"));
   y +=  h;
-  gdk_draw_string (canvas, cfg->headingb, gc, lm + column_x[1], y, "Cesar Miquel");
+  gdk_draw_string (canvas, cfg->headingb, gc, lm + column_x[1], y, _("Cesar Miquel"));
   y +=  h;
-  gdk_draw_string (canvas, cfg->heading, gc, lm + column_x[1], y, "email:");
+  gdk_draw_string (canvas, cfg->heading, gc, lm + column_x[1], y, _("email:"));
   gdk_gc_set_foreground (gc, &cfg->gray50);
-  skip = gdk_string_measure (cfg->heading, "email: ");
+  skip = gdk_string_measure (cfg->heading, _("email: "));
   gdk_draw_string (canvas, cfg->heading, gc, lm + column_x[1] + skip, y, "miquel@df.uba.ar");
 
   y += h;
@@ -108,7 +109,7 @@ AboutRepaint (GtkWidget *widget, gpointer data)
   for(i=0;i<numlines;i++)
     {
       y +=  h;
-      gdk_draw_string (canvas, cfg->small, gc, lm + column_x[0], y, other_info[i]);
+      gdk_draw_string (canvas, cfg->small, gc, lm + column_x[0], y, _(other_info[i]));
     }
 
 
@@ -135,20 +136,20 @@ void
 AboutShowWindow (GtkWidget *widget, gpointer user_data)
 {
   GtkWidget *frame, *drawing_area;
-  int w, h, x, y, i;
+  int w, h, x, y;
 
 #ifdef I_LIKE_GNOME_ABOUT
-  const char *author[] = {"Cesar Miquel (miquel@df.uba.ar)", NULL};
-  char *comments = "This  program  is  part of  the  GNOME  project " 
+  const char *author[] = {N_("Cesar Miquel (miquel@df.uba.ar)"), NULL};
+  char *comments = N_("This  program  is  part of  the  GNOME  project " 
 "for Linux. Logview comes with ABSOLUTELY NO WARRANTY. This is free " 
 "software, and you are welcome to redistribute it under the conditions "
 "of the GNU General Public Licence. The log icon is a courtesy of "
-"Tuomas Kuosmanen (a.k.a tigert).";
+"Tuomas Kuosmanen (a.k.a tigert).");
 
   /* go get logview.xpm in $(prefix)/share/pixmaps/logview */
-  about_window = gnome_about_new ("Logview", LOGVIEW_VERSION,
-           			  "Copyright (C) 1998",
-				  author, comments,
+  about_window = gnome_about_new (_("Logview"), LOGVIEW_VERSION,
+           			  N_("Copyright (C) 1998"),
+				  author, _(comments),
 				  "logview/logview.xpm");
   gtk_widget_show (about_window);
   return;
