@@ -20,6 +20,8 @@
 
 
 #include <time.h>
+#include <config.h>
+#include <gnome.h>
 #include "gtk/gtk.h"
 #include "logview.h"
 #include "close.xpm"
@@ -54,8 +56,6 @@ void CloseCalendar (GtkWidget * widget, gpointer client_data);
 void GotoPrevMonth (GtkWidget * widget, gpointer client_data);
 void GotoNextMonth (GtkWidget * widget, gpointer client_data);
 void MoveMark ();
-void MoveToMark ();
-void InitCalendarData ();
 void HandleMouseMotion (GtkWidget * cv, GdkEventMotion * event);
 void HandleMouseButton( GtkWidget * cv, GdkEventButton * event);
 void DrawCalCursor ();
@@ -63,7 +63,6 @@ void EraseCalCursor ();
 void log_repaint (GtkWidget * cv, GdkRectangle * area);
 void Draw3DBox (GdkDrawable *, GdkGC *, int , int , int , int, GdkColor color[3]);
 int IsLeapYear (int year);
-int RepaintCalendar (GtkWidget * widget, GdkEventExpose * event);
 int GetDayOfWeek (int day, int month, int year);
 void DrawGlassWin (GdkWindow *win, int xs, int ys, int w, int h);
 void set_scrollbar_size (int num_lines);
@@ -130,7 +129,7 @@ CalendarMenu (GtkWidget * widget, gpointer user_data)
    {
       CalendarDialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
       gtk_container_set_border_width (GTK_CONTAINER (CalendarDialog), 1);
-      gtk_window_set_title (GTK_WINDOW (CalendarDialog), "Calendar");
+      gtk_window_set_title (GTK_WINDOW (CalendarDialog), _("Calendar"));
       gtk_signal_connect (GTK_OBJECT (CalendarDialog), "destroy",
 			  GTK_SIGNAL_FUNC (CloseCalendar),
 			  &CalendarDialog);
@@ -150,14 +149,14 @@ CalendarMenu (GtkWidget * widget, gpointer user_data)
       icon = new_pixmap_from_data (leftxpm, CalendarDialog->window, 
 		   &CalendarDialog->style->bg[GTK_STATE_NORMAL]);
       gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-                               "prev", "Prev Month", NULL,
+                               "prev", _("Prev Month"), NULL,
 			       icon,
                                (GtkSignalFunc) GotoPrevMonth, 
 			       toolbar);
       icon = new_pixmap_from_data (rightxpm, CalendarDialog->window, 
 		   &CalendarDialog->style->bg[GTK_STATE_NORMAL]);
       gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-                               "next", "Next Month", NULL,
+                               "next", _("Next Month"), NULL,
 			       icon,
                                (GtkSignalFunc) GotoNextMonth, 
 			       toolbar);
@@ -165,7 +164,7 @@ CalendarMenu (GtkWidget * widget, gpointer user_data)
       icon = new_pixmap_from_data (closexpm, CalendarDialog->window, 
 		   &CalendarDialog->style->bg[GTK_STATE_NORMAL]);
       gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-                               NULL, "Hide calendar", NULL,
+                               NULL, _("Hide calendar"), NULL,
 			       icon,
                                (GtkSignalFunc) CloseCalendar, 
 			       toolbar);
@@ -256,7 +255,7 @@ InitCalendarData ()
 	 mark = mark->next;
 
    if (mark == NULL)
-      ShowErrMessage ("Program error: mark is NULL!");
+      ShowErrMessage (_("Program error: mark is NULL!"));
 
    curmonthmark = mark;
 }
@@ -273,7 +272,8 @@ RepaintCalendar (GtkWidget * widget, GdkEventExpose * event)
    int y, h, w, lm;
    int dayofweek, day, prevmonth;
    static char *dayinletters[] =
-   {"SUN", "MON", "TUE", "WED", "THU", "FRI", "SAT"};
+   {N_("SUN"), N_("MON"), N_("TUE"), N_("WED"),
+    N_("THU"), N_("FRI"), N_("SAT")};
    DateMark *mark;
 
    if (widget != NULL)
@@ -292,7 +292,7 @@ RepaintCalendar (GtkWidget * widget, GdkEventExpose * event)
    /* Draw title */
    y = LOG_LINESEP;
    lm = CALLEFTMARGIN;
-   sprintf (buffer, "%s   %d", month[curmonth], (1900 + curyear));
+   sprintf (buffer, "%s   %d", _(month[curmonth]), (1900 + curyear));
    gdk_gc_set_foreground (gc, &cfg->green);
    gdk_draw_string (CalendarCanvas, cfg->headingb, gc, lm, y, buffer);
    y += 5;
@@ -304,7 +304,7 @@ RepaintCalendar (GtkWidget * widget, GdkEventExpose * event)
    y += h + 3;
    for (day = 0; day <= SATURDAY; day++)
    {
-      sprintf (buffer, "%s", dayinletters[day]);
+      sprintf (buffer, "%s", _(dayinletters[day]));
       gdk_draw_string (CalendarCanvas, cfg->fixedb, gc, lm + w * day + XSEP, y, buffer);
    }
    gdk_draw_line (CalendarCanvas, gc, lm, y + 3, lm + w * 7, y + 3);
@@ -609,11 +609,12 @@ MoveMark ()
       mark = FindNextMark ();
    else if (curyear < mark->fulldate.tm_year)
       mark = FindPrevMark ();
-   else if (curyear == mark->fulldate.tm_year)
+   else if (curyear == mark->fulldate.tm_year) {
       if (curmonth > mark->fulldate.tm_mon)
 	 mark = FindNextMark ();
       else
 	 mark = FindPrevMark ();
+   }
 
    if (mark == NULL)
       return;
