@@ -26,6 +26,7 @@
 #include <malloc.h>
 #include <config.h>
 #include <string.h>
+#include <gnome.h>
 #include "logview.h"
 #include "logrtns.h"
 #include "gtk/gtk.h"
@@ -82,9 +83,9 @@ char *deflognames[] =
 {PATH_MESSAGES};
 
 char *month[12] =
-{"January", "February", "March", "April", "May",
- "June", "July", "August", "September", "October",
- "November", "December"};
+{N_("January"), N_("February"), N_("March"), N_("April"), N_("May"),
+ N_("June"), N_("July"), N_("August"), N_("September"), N_("October"),
+ N_("November"), N_("December")};
 extern GtkWidget *main_win_scrollbar;
 
 /*
@@ -111,8 +112,6 @@ void Draw3DBox (GdkDrawable *win, GdkGC *gc, int x, int y, int w, int h, GdkColo
 void CloseApp ();
 void UpdateStatusArea ();
 void InitCalendarData ();
-void ScrollUp (int howmuch);
-void ScrollDown (int howmuch);
 void change_log (int direction);
 void create_zoom_view (GtkWidget * widget, gpointer user_data);
 void close_zoom_view (GtkWidget * widget, GtkWindow ** window);
@@ -220,8 +219,6 @@ void
 HandleLogKeyboard (GtkWidget * win, GdkEventKey * event_key)
 {
   GtkAdjustment *adj;
-  int ln, y;
-  DateMark *mark;
   guint key;
 
   /* Check that there is at least one log */
@@ -591,7 +588,7 @@ DrawMonthHeader (LogLine * line, int y)
    Draw3DBox (canvas, gc, 5, y - log_line_sep + skip , LOG_CANVAS_W - 10, 2*log_line_sep-skip, color);
 
    gdk_gc_set_foreground (gc, &cfg->black);
-   sprintf (buf, "%s %d", month[(int) line->month], line->date);
+   sprintf (buf, "%s %d", _(month[(int) line->month]), line->date);
    gdk_draw_string (canvas, cfg->headingb, gc, LOG_COL1 - 1, centery + 1, buf);
    gdk_gc_set_foreground (gc, &cfg->white);
    gdk_draw_string (canvas, cfg->headingb, gc, LOG_COL1, centery, buf);
