@@ -19,9 +19,10 @@
 
     ---------------------------------------------------------------------- */
 
-
+#include "config.h"
 #include "logview.h"
 #include "logrtns.h"
+#include <gnome.h>
 
 /*
  * -----------------
@@ -92,14 +93,14 @@ OpenLogFile (char *filename)
    tlog = malloc (sizeof (Log));
    if (tlog == NULL)
    {
-      ShowErrMessage ("Not enough memory!\n");
+      ShowErrMessage (_("Not enough memory!\n"));
       return ((Log *) NULL);
    }
    /* Alloc memory for pages ------------------------------ */
    tlog->currentpg = (Page *) malloc (sizeof (Page));
    if (tlog->currentpg == NULL)
    {
-      ShowErrMessage ("Out of memory!\n");
+      ShowErrMessage (_("Out of memory!\n"));
       free (tlog);
       return (Log *) NULL;
    }
@@ -124,7 +125,7 @@ OpenLogFile (char *filename)
    tlog->fp = fopen (filename, "r");
    if (tlog->fp == NULL)
    {
-      ShowErrMessage ("Unable to open logfile!\n");
+      ShowErrMessage (_("Unable to open logfile!\n"));
       return (Log *) NULL;
    }
    fseek (tlog->fp, -1L, SEEK_END);
@@ -178,16 +179,16 @@ isLogFile (char *filename)
    /* Check that its a regular file       */
    if (!S_ISREG (fstatus.st_mode))
    {
-      sprintf (buff, "%s is not a regular file.", filename);
+      sprintf (buff, _("%s is not a regular file."), filename);
       ShowErrMessage (buff);
       return FALSE;
    }
    /* File unreadable                     */
    if ((fstatus.st_mode & S_IRUSR) == 0)
    {
-      sprintf (buff, "%s is not user readable. Probably has read-only permission. 
-      Either run the program as root or ask the sysadmin to change the permissions 
-      on the file.", filename);
+      sprintf (buff, _("%s is not user readable. Probably has read-only "
+      "permission. Either run the program as root or ask the sysadmin to "
+      "change the permissions on the file."), filename);
       ShowErrMessage (buff);
       return FALSE;
    }
@@ -197,7 +198,7 @@ isLogFile (char *filename)
    fp = fopen (filename, "r");
    if (fp == NULL)
    {
-      sprintf (buff, "%s could not be opened.", filename);
+      sprintf (buff, _("%s could not be opened."), filename);
       ShowErrMessage (buff);
       return FALSE;
    }
@@ -206,7 +207,7 @@ isLogFile (char *filename)
    token = strtok (buff, " ");
    if (strlen (buff) != 3)
    {
-      sprintf (buff, "%s not a log file.", filename);
+      sprintf (buff, _("%s not a log file."), filename);
       ShowErrMessage (buff);
       return FALSE;
    }
@@ -216,7 +217,7 @@ isLogFile (char *filename)
 
    if (i == 12)
    {
-      sprintf (buff, "%s not a log file.", filename);
+      sprintf (buff, _("%s not a log file."), filename);
       ShowErrMessage (buff);
       return FALSE;
    }
@@ -551,7 +552,8 @@ ParseLine (char *buff, LogLine * line)
      return;
    if (match_line_in_db (line, regexp_db))
      {
-       sprintf (scratch, "Expression /%s/ matched.", line->description->regexp);
+       sprintf (scratch, _("Expression /%s/ matched."),
+		 line->description->regexp);
        line->description->description = g_strdup(scratch);
      }
      ---------------------------- */
@@ -613,7 +615,7 @@ ReadLogStats (Log * log)
    curmark = malloc (sizeof (DateMark));
    if (curmark == NULL)
    {
-      ShowErrMessage ("ReadLogStats: out of memory");
+      ShowErrMessage (_("ReadLogStats: out of memory"));
       exit (0);
    }
    log->lstats.firstmark = curmark;
@@ -644,7 +646,7 @@ ReadLogStats (Log * log)
      curmark->next = malloc (sizeof (DateMark));
      if (curmark->next == NULL)
        {
-	 ShowErrMessage ("ReadLogStats: out of memory");
+	 ShowErrMessage (_("ReadLogStats: out of memory"));
 	 exit (0);
        }
      curmark->next->prev = curmark;
@@ -775,7 +777,7 @@ UpdateLogStats( Log *log )
      curmark->next = malloc (sizeof (DateMark));
      if (curmark->next == NULL)
        {
-	 ShowErrMessage ("ReadLogStats: out of memory");
+	 ShowErrMessage (_("ReadLogStats: out of memory"));
 	 exit (0);
        }
      curmark->next->prev = curmark;
