@@ -197,5 +197,14 @@ void ShowErrMessage (char *msg);
 GtkWidget *AddMenu (MenuItem * items);
 GtkWidget *ButtonWithPixmap (char **xpmdata, int w, int h);
 ConfigData *CreateConfig();
+void set_scrollbar_size (int);
+int repaint_zoom (GtkWidget * widget, GdkEventExpose * event);
+void MoveToMark (Log *log);
+void ScrollUp (int howmuch);
+void ScrollDown (int howmuch);
+void InitCalendarData ();
+int RepaintCalendar (GtkWidget * widget, GdkEventExpose * event);
+int read_descript_db (char *filename, GList **db);
+int find_tag_in_db (LogLine *line, GList *db);
 
 #endif /* __LOGVIEW_H__ */
